@@ -1,7 +1,7 @@
 package Perinci::Result::Format::Lite;
 
-our $DATE = '2017-08-09'; # DATE
-our $VERSION = '0.26'; # VERSION
+our $DATE = '2017-12-09'; # DATE
+our $VERSION = '0.270'; # VERSION
 
 use 5.010001;
 #IFUNBUILT
@@ -201,16 +201,14 @@ sub __gen_table {
                     my $fmt = $fmt_opts->{sprintf} // '%.2f%%';
                     $row->[$j] = sprintf($fmt, $row->[$j] * 100);
                 } elsif ($fmt_name eq 'number') {
-                    $nf //= do {
-                        require Number::Format;
-                        Number::Format->new(
-                            THOUSANDS_SEP => $fmt_opts->{thousands_sep} // ',',
-                            DECIMAL_POINT => $fmt_opts->{decimal_point} // '.',
-                            DECIMAL_FILL  => $fmt_opts->{decimal_fill} // 1,
-                        );
-                    };
-                    $row->[$j] = $nf->format_number(
-                        $row->[$j], $fmt_opts->{precision} // 0);
+                    require Number::Format::BigFloat;
+                    $row->[$j] = Number::Format::BigFloat::format_number(
+                        $row->[$j], {
+                            thousands_sep  => $fmt_opts->{thousands_sep} // ',',
+                            decimal_point  => $fmt_opts->{decimal_point} // '.',
+                            decimal_digits => $fmt_opts->{precision} // 0,
+                            # XXX decimal_fill
+                        });
                 }
             }
         }
@@ -519,7 +517,7 @@ Perinci::Result::Format::Lite - Format enveloped result
 
 =head1 VERSION
 
-This document describes version 0.26 of Perinci::Result::Format::Lite (from Perl distribution Perinci-Result-Format-Lite), released on 2017-08-09.
+This document describes version 0.270 of Perinci::Result::Format::Lite (from Perl distribution Perinci-Result-Format-Lite), released on 2017-12-09.
 
 =head1 SYNOPSIS
 
